/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.sinfo.common;

import java.util.HashSet;
import java.util.Set;

import org.dive4elements.artifactdatabase.state.ArtifactAndFacet;
import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.artifacts.CallMeta;
import org.dive4elements.river.artifacts.resources.Resources;
import org.dive4elements.river.artifacts.sinfo.predefinedchannel.PredefinedChannelFacet;
import org.dive4elements.river.exports.DiagramGenerator;
import org.dive4elements.river.themes.ThemeDocument;

/**
 * Processor to generate a data series for river channel depth data loaded from the database
 *
 * @author Matthias Schäfer
 *
 */
public class PredefinedChannelDepthProcessor extends AbstractSInfoProcessor {

    // private final static Logger log = Logger.getLogger(PredefinedChannelDepthProcessor.class);

    public static final String FACET_PREDEFINED_CHANNEL_DEPTH = "sinfo_facet_predefined_channel_depth";

    private static final String I18N_AXIS_LABEL = "sinfo.chart.flow_depth.section.yaxis.label";

    private static final String I18N_SERIES_NAME_PATTERN = "predefinedchannel.depth.title";

    private static final Set<String> HANDLED_FACET_TYPES = new HashSet<>();

    static {
        HANDLED_FACET_TYPES.add(FACET_PREDEFINED_CHANNEL_DEPTH);
    }

    public PredefinedChannelDepthProcessor() {
        super(I18N_AXIS_LABEL, HANDLED_FACET_TYPES);
    }

    public static Facet createFacet(final CallMeta callMeta, final String seriesName) {
        return new PredefinedChannelFacet(FACET_PREDEFINED_CHANNEL_DEPTH,
                Resources.getMsg(callMeta, I18N_SERIES_NAME_PATTERN, I18N_SERIES_NAME_PATTERN, seriesName), I18N_AXIS_LABEL);
    }

    @Override
    protected String generateSeries(final DiagramGenerator generator, final ArtifactAndFacet bundle, final ThemeDocument theme, final boolean visible) {

        return buildSeriesForType(generator, bundle, theme, visible, SInfoResultType.collisionCount, null);
    }
}